<?php
/**
 * Video Gallery section
 *
 * This is the template for the content of video gallery section
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */
if ( ! function_exists( 'travel_master_pro_add_video_gallery_section' ) ) :
    /**
    * Add video gallery section
    *
    *@since Travel Master Pro 1.0.0
    */
    function travel_master_pro_add_video_gallery_section() {
        $options = travel_master_pro_get_theme_options();
        // Check if video gallery is enabled on frontpage
        $video_gallery_enable = apply_filters( 'travel_master_pro_section_status', true, 'video_gallery_section_enable' );

        if ( true !== $video_gallery_enable ) {
            return false;
        }
        // Get video gallery section details
        $section_details = array();
        $section_details = apply_filters( 'travel_master_pro_filter_video_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video gallery section now.
        travel_master_pro_render_video_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_master_pro_get_video_gallery_section_details' ) ) :
    /**
    * video gallery section details.
    *
    * @since Travel Master Pro 1.0.0
    * @param array $input video gallery section details.
    */
    function travel_master_pro_get_video_gallery_section_details( $input ) {
        $options = travel_master_pro_get_theme_options();

        // Content type.
        $video_gallery_content_type  = $options['video_gallery_content_type'];
        
        $content = array();
        switch ( $video_gallery_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['video_gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['video_gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 2,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['video_gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['video_gallery_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 2,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video gallery section content details.
add_filter( 'travel_master_pro_filter_video_gallery_section_details', 'travel_master_pro_get_video_gallery_section_details' );


if ( ! function_exists( 'travel_master_pro_render_video_gallery_section' ) ) :
  /**
   * Start video gallery section
   *
   * @return string video gallery content
   * @since Travel Master Pro 1.0.0
   *
   */
   function travel_master_pro_render_video_gallery_section( $content_details = array() ) {
        $options = travel_master_pro_get_theme_options();
        $video_gallery_content_type  = $options['video_gallery_content_type'];
        ?>

        <div id="featured-videos" class="relative page-section">
            <div class="wrapper">
                <div class="section-content clear col-2">
                    <div class="video-wrapper">
                        <?php if ( ! empty( $options['video_gallery_video_title'] ) ) : ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $options['video_gallery_video_title'] ); ?></h2>
                            </div><!-- .section-header -->
                        <?php endif; ?>

                        <article>
                            <?php if ( ! empty( $options['video_gallery_video_url'] ) ) : ?>
                                <div class="featured-video">
                                    <?php echo do_shortcode( '[video src="' . esc_url( $options['video_gallery_video_url'] ) . '"]' ); ?>
                                </div><!-- .featured-video -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( ! empty( $options['video_gallery_sub_title'] ) ) : ?>
                                    <span class="section-subtitle"><?php echo esc_html( $options['video_gallery_sub_title'] ); ?></span><!-- .cat-links -->
                                <?php endif; 

                                if ( ! empty( $options['video_gallery_title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $options['video_gallery_title'] ); ?></h2>
                                    </header>
                                <?php endif; ?>

                            </div><!-- .entry-container -->
                        </article>
                    </div><!-- .video-wrapper -->

                    <?php if ( ! empty( $content_details ) ) : ?>
                        <div class="photos-wrapper">
                            <?php if ( ! empty( $options['video_gallery_post_title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $options['video_gallery_post_title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; ?>

                            <div class="photo-list-wrapper">
                                <?php foreach ( $content_details as $content ) : ?>
                                    <article>
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                            <div class="photo-count">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                    <?php echo travel_master_pro_get_svg( array( 'icon' => 'camera' ) ); ?>
                                                </a>
                                            </div><!-- .photo-count -->  
                                        </div><!-- .featured-image -->

                                        <div class="entry-container">
                                            <?php if ( 'page' !== $video_gallery_content_type ) : ?>
                                                <span class="cat-links">
                                                    <?php the_category( '', '', $content['id'] ); ?>
                                                </span><!-- .cat-links -->
                                            <?php endif; ?>

                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        </div><!-- .entry-container -->
                                    </article>
                                <?php endforeach; ?>
                            </div><!-- .photo-list-wrapper -->
                        </div><!-- .photos-wrapper -->
                    <?php endif; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- .featured-videos -->

    <?php }
endif;